pub struct PackedIndex(/* private fields */);Expand description
Wrapper type for a usize in which the lower 5 bits represent the index of 1 of 20 icosahedral faces and the
remaining bits represent the index of a triangular subdivision within that face.
Implementations